==> jc-1.4.0.tar.gz: jas/IntegerCP.h <==
// public class jas.IntegerCP

// class file dependencies
// @dep_class c0e5264359137f3 jas_CP
// @dep_class de74763e343fa9d5 jas_IntegerCP
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header jas_CP

#include "jas/CP.h"

#ifndef _JC_jas_IntegerCP_H_
#define _JC_jas_IntegerCP_H_

// Forward structure declarations
struct _jc_jas_ClassEnv$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_IntegerCP$sub_refs	_jc_jas_IntegerCP$sub_refs;
typedef struct _jc_jas_IntegerCP$sub_nonrefs	_jc_jas_IntegerCP$sub_nonrefs;
typedef struct _jc_jas_IntegerCP$refs	_jc_jas_IntegerCP$refs;
typedef struct _jc_jas_IntegerCP$nonrefs	_jc_jas_IntegerCP$nonrefs;
typedef struct _jc_jas_IntegerCP$object	_jc_jas_IntegerCP$object;

typedef const struct _jc_jas_IntegerCP$vmethods	_jc_jas_IntegerCP$vmethods;
typedef const struct _jc_jas_IntegerCP$vtable	_jc_jas_IntegerCP$vtable;
typedef const struct _jc_jas_IntegerCP$vtype	_jc_jas_IntegerCP$vtype;

// Constructors
extern void _jc_jas_IntegerCP$method$_init$7f1776288300b98d(_jc_env *, struct _jc_jas_IntegerCP$object *, jint);

// Virtual methods
extern void _jc_jas_IntegerCP$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_IntegerCP$object *, struct _jc_jas_ClassEnv$object *);
extern void _jc_jas_IntegerCP$method$write$c5719140f8114b75(_jc_env *, struct _jc_jas_IntegerCP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *);

// Virtual method descriptors
extern _jc_method _jc_jas_IntegerCP$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_IntegerCP$method_info$write$c5719140f8114b75;

// Virtual methods structure
struct _jc_jas_IntegerCP$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_IntegerCP$object *, struct _jc_jas_ClassEnv$object *);
	void	(*write$c5719140f8114b75)(_jc_env *, struct _jc_jas_IntegerCP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *);
};

// Vtable
struct _jc_jas_IntegerCP$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_CP$vmethods	jas_CP;
	_jc_jas_IntegerCP$vmethods	jas_IntegerCP;
};

// Vtype
struct _jc_jas_IntegerCP$vtype {
	_jc_type			type;
	_jc_jas_IntegerCP$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_IntegerCP$sub_refs {
};

// Reference instance fields (object)
struct _jc_jas_IntegerCP$refs {
    _jc_jas_IntegerCP$sub_refs	jas_IntegerCP;
    _jc_jas_CP$sub_refs	jas_CP;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_IntegerCP$sub_nonrefs {
	jint	val;
};

// Non-reference instance fields (object)
struct _jc_jas_IntegerCP$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_CP$sub_nonrefs	jas_CP;
    _jc_jas_IntegerCP$sub_nonrefs	jas_IntegerCP;
};

// Object instance structure
struct _jc_jas_IntegerCP$object {
	_jc_jas_IntegerCP$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_IntegerCP$vtype	*vtype;
	_jc_jas_IntegerCP$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_IntegerCP$vtype _jc_jas_IntegerCP$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_IntegerCP, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_IntegerCP$class_object;

#endif	/* _JC_jas_IntegerCP_H_ */

==> jc-1.4.6.tar.gz: jas/IntegerCP.h <==
// public class jas.IntegerCP

// class file dependencies
// @dep_class c0e5264359137f3 jas_CP
// @dep_class de74763e343fa9d5 jas_IntegerCP
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header jas_CP

#include "jas/CP.h"

#ifndef _JC_jas_IntegerCP_H_
#define _JC_jas_IntegerCP_H_

// Forward structure declarations
struct _jc_jas_ClassEnv$object;
struct _jc_java_io_DataOutputStream$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_jas_IntegerCP$sub_refs	_jc_jas_IntegerCP$sub_refs;
typedef struct _jc_jas_IntegerCP$sub_nonrefs	_jc_jas_IntegerCP$sub_nonrefs;
typedef struct _jc_jas_IntegerCP$refs	_jc_jas_IntegerCP$refs;
typedef struct _jc_jas_IntegerCP$nonrefs	_jc_jas_IntegerCP$nonrefs;
typedef struct _jc_jas_IntegerCP$object	_jc_jas_IntegerCP$object;

typedef const struct _jc_jas_IntegerCP$vmethods	_jc_jas_IntegerCP$vmethods;
typedef const struct _jc_jas_IntegerCP$vtable	_jc_jas_IntegerCP$vtable;
typedef const struct _jc_jas_IntegerCP$vtype	_jc_jas_IntegerCP$vtype;

// Constructors
extern void _jc_jas_IntegerCP$method$_init$7f1776288300b98d(_jc_env *, struct _jc_jas_IntegerCP$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_jas_IntegerCP$method$resolve$f7bbca8128967cc2(_jc_env *, struct _jc_jas_IntegerCP$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
extern void _jc_jas_IntegerCP$method$write$c5719140f8114b75(_jc_env *, struct _jc_jas_IntegerCP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_jas_IntegerCP$method_info$resolve$f7bbca8128967cc2;
extern _jc_method _jc_jas_IntegerCP$method_info$write$c5719140f8114b75;

// Virtual methods structure
struct _jc_jas_IntegerCP$vmethods {
	void	(*resolve$f7bbca8128967cc2)(_jc_env *, struct _jc_jas_IntegerCP$object *, struct _jc_jas_ClassEnv$object *) _JC_JCNI_ATTR;
	void	(*write$c5719140f8114b75)(_jc_env *, struct _jc_jas_IntegerCP$object *, struct _jc_jas_ClassEnv$object *, struct _jc_java_io_DataOutputStream$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_jas_IntegerCP$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_jas_CP$vmethods	jas_CP;
	_jc_jas_IntegerCP$vmethods	jas_IntegerCP;
};

// Vtype
struct _jc_jas_IntegerCP$vtype {
	_jc_type			type;
	_jc_jas_IntegerCP$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_jas_IntegerCP$sub_refs {
};

// Reference instance fields (object)
struct _jc_jas_IntegerCP$refs {
    _jc_jas_IntegerCP$sub_refs	jas_IntegerCP;
    _jc_jas_CP$sub_refs	jas_CP;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_jas_IntegerCP$sub_nonrefs {
	jint	val;
};

// Non-reference instance fields (object)
struct _jc_jas_IntegerCP$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_jas_CP$sub_nonrefs	jas_CP;
    _jc_jas_IntegerCP$sub_nonrefs	jas_IntegerCP;
};

// Object instance structure
struct _jc_jas_IntegerCP$object {
	_jc_jas_IntegerCP$refs	refs[0];
	_jc_word		lockword;
	_jc_jas_IntegerCP$vtype	*vtype;
	_jc_jas_IntegerCP$nonrefs	nonrefs;
};

// Type structure
extern _jc_jas_IntegerCP$vtype _jc_jas_IntegerCP$type;

// Array types class info structures
_JC_DECL_ARRAYS(jas_IntegerCP, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_jas_IntegerCP$class_object;

#endif	/* _JC_jas_IntegerCP_H_ */
